package Bundle::Locale::CLDR::Southernasia;

use version;

our $VERSION = version->declare('v0.44.1');

=head1 NAME

Bundle::Locale::CLDR::Southernasia

=head1 CONTENTS

Locale::CLDR::Locales::As 0.44.1

Locale::CLDR::Locales::Bn 0.44.1

Locale::CLDR::Locales::Bo 0.44.1

Locale::CLDR::Locales::Dv 0.44.1

Locale::CLDR::Locales::Dz 0.44.1

Locale::CLDR::Locales::Fa 0.44.1

Locale::CLDR::Locales::Gu 0.44.1

Locale::CLDR::Locales::Hi 0.44.1

Locale::CLDR::Locales::Kn 0.44.1

Locale::CLDR::Locales::Ks 0.44.1

Locale::CLDR::Locales::Ml 0.44.1

Locale::CLDR::Locales::Mr 0.44.1

Locale::CLDR::Locales::Ne 0.44.1

Locale::CLDR::Locales::Or 0.44.1

Locale::CLDR::Locales::Pa 0.44.1

Locale::CLDR::Locales::Ps 0.44.1

Locale::CLDR::Locales::Sa 0.44.1

Locale::CLDR::Locales::Sd 0.44.1

Locale::CLDR::Locales::Si 0.44.1

Locale::CLDR::Locales::Ta 0.44.1

Locale::CLDR::Locales::Te 0.44.1

Locale::CLDR::Locales::Ur 0.44.1

Locale::CLDR::Locales::Bal 0.44.1

Locale::CLDR::Locales::Bgc 0.44.1

Locale::CLDR::Locales::Bgn 0.44.1

Locale::CLDR::Locales::Bho 0.44.1

Locale::CLDR::Locales::Brx 0.44.1

Locale::CLDR::Locales::Ccp 0.44.1

Locale::CLDR::Locales::Ckb 0.44.1

Locale::CLDR::Locales::Doi 0.44.1

Locale::CLDR::Locales::Kok 0.44.1

Locale::CLDR::Locales::Kxv 0.44.1

Locale::CLDR::Locales::Lrc 0.44.1

Locale::CLDR::Locales::Mai 0.44.1

Locale::CLDR::Locales::Mni 0.44.1

Locale::CLDR::Locales::Mzn 0.44.1

Locale::CLDR::Locales::Raj 0.44.1

Locale::CLDR::Locales::Rhg 0.44.1

Locale::CLDR::Locales::Sat 0.44.1

Locale::CLDR::Locales::Sdh 0.44.1

Locale::CLDR::Locales::Skr 0.44.1

Locale::CLDR::Locales::Trw 0.44.1

Locale::CLDR::Locales::Xnr 0.44.1

Locale::CLDR::Locales::As::Beng 0.44.1

Locale::CLDR::Locales::Az::Arab 0.44.1

Locale::CLDR::Locales::Bn::Beng 0.44.1

Locale::CLDR::Locales::Bo::Tibt 0.44.1

Locale::CLDR::Locales::Dv::Thaa 0.44.1

Locale::CLDR::Locales::Dz::Tibt 0.44.1

Locale::CLDR::Locales::Fa::Arab 0.44.1

Locale::CLDR::Locales::Gu::Gujr 0.44.1

Locale::CLDR::Locales::Hi::Deva 0.44.1

Locale::CLDR::Locales::Hi::Latn 0.44.1

Locale::CLDR::Locales::Kn::Knda 0.44.1

Locale::CLDR::Locales::Ks::Arab 0.44.1

Locale::CLDR::Locales::Ks::Deva 0.44.1

Locale::CLDR::Locales::Ml::Mlym 0.44.1

Locale::CLDR::Locales::Mr::Deva 0.44.1

Locale::CLDR::Locales::Ne::Deva 0.44.1

Locale::CLDR::Locales::Or::Orya 0.44.1

Locale::CLDR::Locales::Pa::Arab 0.44.1

Locale::CLDR::Locales::Pa::Guru 0.44.1

Locale::CLDR::Locales::Ps::Arab 0.44.1

Locale::CLDR::Locales::Sa::Deva 0.44.1

Locale::CLDR::Locales::Sd::Arab 0.44.1

Locale::CLDR::Locales::Sd::Deva 0.44.1

Locale::CLDR::Locales::Si::Sinh 0.44.1

Locale::CLDR::Locales::Ta::Taml 0.44.1

Locale::CLDR::Locales::Te::Telu 0.44.1

Locale::CLDR::Locales::Ur::Arab 0.44.1

Locale::CLDR::Locales::Uz::Arab 0.44.1

Locale::CLDR::Locales::Bal::Arab 0.44.1

Locale::CLDR::Locales::Bal::Latn 0.44.1

Locale::CLDR::Locales::Bgc::Deva 0.44.1

Locale::CLDR::Locales::Bgn::Arab 0.44.1

Locale::CLDR::Locales::Bho::Deva 0.44.1

Locale::CLDR::Locales::Brx::Deva 0.44.1

Locale::CLDR::Locales::Ccp::Cakm 0.44.1

Locale::CLDR::Locales::Ckb::Arab 0.44.1

Locale::CLDR::Locales::Doi::Deva 0.44.1

Locale::CLDR::Locales::Kok::Deva 0.44.1

Locale::CLDR::Locales::Kxv::Deva 0.44.1

Locale::CLDR::Locales::Kxv::Latn 0.44.1

Locale::CLDR::Locales::Kxv::Orya 0.44.1

Locale::CLDR::Locales::Kxv::Telu 0.44.1

Locale::CLDR::Locales::Lrc::Arab 0.44.1

Locale::CLDR::Locales::Mai::Deva 0.44.1

Locale::CLDR::Locales::Mni::Beng 0.44.1

Locale::CLDR::Locales::Mni::Mtei 0.44.1

Locale::CLDR::Locales::Mzn::Arab 0.44.1

Locale::CLDR::Locales::Raj::Deva 0.44.1

Locale::CLDR::Locales::Rhg::Rohg 0.44.1

Locale::CLDR::Locales::Sat::Deva 0.44.1

Locale::CLDR::Locales::Sat::Olck 0.44.1

Locale::CLDR::Locales::Sdh::Arab 0.44.1

Locale::CLDR::Locales::Skr::Arab 0.44.1

Locale::CLDR::Locales::Trw::Arab 0.44.1

Locale::CLDR::Locales::Xnr::Deva 0.44.1

Locale::CLDR::Locales::As::Beng::In 0.44.1

Locale::CLDR::Locales::Az::Arab::Ir 0.44.1

Locale::CLDR::Locales::Bn::Beng::Bd 0.44.1

Locale::CLDR::Locales::Bn::Beng::In 0.44.1

Locale::CLDR::Locales::Bo::Tibt::In 0.44.1

Locale::CLDR::Locales::Dv::Thaa::Mv 0.44.1

Locale::CLDR::Locales::Dz::Tibt::Bt 0.44.1

Locale::CLDR::Locales::En::Latn::In 0.44.1

Locale::CLDR::Locales::En::Latn::Mv 0.44.1

Locale::CLDR::Locales::En::Latn::Pk 0.44.1

Locale::CLDR::Locales::Fa::Arab::Af 0.44.1

Locale::CLDR::Locales::Fa::Arab::Ir 0.44.1

Locale::CLDR::Locales::Gu::Gujr::In 0.44.1

Locale::CLDR::Locales::Hi::Deva::In 0.44.1

Locale::CLDR::Locales::Hi::Latn::In 0.44.1

Locale::CLDR::Locales::Kn::Knda::In 0.44.1

Locale::CLDR::Locales::Ks::Arab::In 0.44.1

Locale::CLDR::Locales::Ks::Deva::In 0.44.1

Locale::CLDR::Locales::Ml::Mlym::In 0.44.1

Locale::CLDR::Locales::Mr::Deva::In 0.44.1

Locale::CLDR::Locales::Ne::Deva::In 0.44.1

Locale::CLDR::Locales::Ne::Deva::Np 0.44.1

Locale::CLDR::Locales::Or::Orya::In 0.44.1

Locale::CLDR::Locales::Pa::Arab::Pk 0.44.1

Locale::CLDR::Locales::Pa::Guru::In 0.44.1

Locale::CLDR::Locales::Ps::Arab::Af 0.44.1

Locale::CLDR::Locales::Ps::Arab::Pk 0.44.1

Locale::CLDR::Locales::Sa::Deva::In 0.44.1

Locale::CLDR::Locales::Sd::Arab::Pk 0.44.1

Locale::CLDR::Locales::Sd::Deva::In 0.44.1

Locale::CLDR::Locales::Si::Sinh::Lk 0.44.1

Locale::CLDR::Locales::Ta::Taml::In 0.44.1

Locale::CLDR::Locales::Ta::Taml::Lk 0.44.1

Locale::CLDR::Locales::Te::Telu::In 0.44.1

Locale::CLDR::Locales::Ur::Arab::In 0.44.1

Locale::CLDR::Locales::Ur::Arab::Pk 0.44.1

Locale::CLDR::Locales::Uz::Arab::Af 0.44.1

Locale::CLDR::Locales::Bal::Arab::Pk 0.44.1

Locale::CLDR::Locales::Bal::Latn::Pk 0.44.1

Locale::CLDR::Locales::Bgc::Deva::In 0.44.1

Locale::CLDR::Locales::Bgn::Arab::Af 0.44.1

Locale::CLDR::Locales::Bgn::Arab::Ir 0.44.1

Locale::CLDR::Locales::Bgn::Arab::Pk 0.44.1

Locale::CLDR::Locales::Bho::Deva::In 0.44.1

Locale::CLDR::Locales::Brx::Deva::In 0.44.1

Locale::CLDR::Locales::Ccp::Cakm::Bd 0.44.1

Locale::CLDR::Locales::Ccp::Cakm::In 0.44.1

Locale::CLDR::Locales::Ckb::Arab::Ir 0.44.1

Locale::CLDR::Locales::Doi::Deva::In 0.44.1

Locale::CLDR::Locales::En::Latn::001 0.44.1

Locale::CLDR::Locales::Kok::Deva::In 0.44.1

Locale::CLDR::Locales::Kxv::Deva::In 0.44.1

Locale::CLDR::Locales::Kxv::Latn::In 0.44.1

Locale::CLDR::Locales::Kxv::Orya::In 0.44.1

Locale::CLDR::Locales::Kxv::Telu::In 0.44.1

Locale::CLDR::Locales::Lrc::Arab::Ir 0.44.1

Locale::CLDR::Locales::Mai::Deva::In 0.44.1

Locale::CLDR::Locales::Mni::Beng::In 0.44.1

Locale::CLDR::Locales::Mni::Mtei::In 0.44.1

Locale::CLDR::Locales::Mzn::Arab::Ir 0.44.1

Locale::CLDR::Locales::Raj::Deva::In 0.44.1

Locale::CLDR::Locales::Rhg::Rohg::Bd 0.44.1

Locale::CLDR::Locales::Sat::Deva::In 0.44.1

Locale::CLDR::Locales::Sat::Olck::In 0.44.1

Locale::CLDR::Locales::Sdh::Arab::Ir 0.44.1

Locale::CLDR::Locales::Skr::Arab::Pk 0.44.1

Locale::CLDR::Locales::Trw::Arab::Pk 0.44.1

Locale::CLDR::Locales::Xnr::Deva::In 0.44.1


=cut

1;

